#ifndef GAME_HPP
#define GAME_HPP
#include "menu.hpp"
extern player Player;
extern int score;
extern int life;
extern int pauseOption;
extern player history[100];
extern int historyCount;
void render();
void renderPanel();
bool game();
bool game(int);
void HideCursor(bool visible);
void setColor(int color);
void playBeep(int F, int T);

//History
void saveHistory();
int sort();
void loadHistory();
extern int Hoption;
void loadScoresAndPrint(char name[]);
bool printHistory(int historyCount);

//Load Game
void saveGame(player &p);
void setAndMarkAsActive(int index);
void loadPlayer();
bool printLoadGame();
extern int loadOption;
#endif